==> otu-5000-18.54.tar: acterna/release/smartotu/app/services/setup/SMTCustomFirewallDto.php <==
<?php
// *********************************************************
// NOTICE: All rights reserved. This material contains the
// trade secrets and confidential information of JDSU
// which embody substantial creative effort,
// ideas and expressions. No part of this material may be
// reproduced or transmitted in any form or by any means,
// electronic, mechanical, optical or otherwise, including
// photocopying and recording or in connection with any
// information storage or retrieval system, without
// specific written permission from Viavi Solutions
// Copyright JDSU 2016. All rights reserved.
// *********************************************************
namespace app\services\setup;


use app\util\SMTRwDto;

/**
 * 
 * @author Sylvain Desplat
 */
class SMTCustomFirewallDto extends SMTRwDto
{
	protected $customFirewallConfig = array();
		
	/**
	 * Set array of port where email must be sent
	 * 
	 * @param string[] $customFirewallConfig
	 */
	public function setCustomFirewall( array $customFirewallConfig )
	{
		$this->customFirewallConfig = $customFirewallConfig;
	}
	
	/**
	 * @return String[]
	 */
	public function getCustomFirewall()
	{
		return $this->customFirewallConfig;
	}
	
	/**
	 * Serialize as Json data the user object.<br>
	 *
	 * @return $objectProperties the object properties serialized as a Json string.
	 */
	function getJsonData()
	{
		$objectProperties = get_object_vars($this);
		$this->serializeObjectAsJsonData( $objectProperties );
		return $objectProperties;
	}

	/**
	 * Returns Dto class name.
	 *
	 * @return string the dtop class name
	 */
	function getDtoClassName()
	{
		return get_class();
	}

	/**
	 * Create the Dto from a Json Dto in an array
	 *
	 * @param array $json_array json data in an array
	 *
	 * @return \app\services\setup\SMTEmailPortFilterDto
	 */
	static function getInstance( array &$json_array )
	{
		return self::forge( get_class(), $json_array );
	}
}


?>

==> otu-5000-24.10020.tar: acterna/release/smartotu/app/services/setup/SMTCustomFirewallDto.php <==
<?php
// *********************************************************
// NOTICE: All rights reserved. This material contains the
// trade secrets and confidential information of JDSU
// which embody substantial creative effort,
// ideas and expressions. No part of this material may be
// reproduced or transmitted in any form or by any means,
// electronic, mechanical, optical or otherwise, including
// photocopying and recording or in connection with any
// information storage or retrieval system, without
// specific written permission from Viavi Solutions
// Copyright JDSU 2016. All rights reserved.
// *********************************************************
namespace app\services\setup;


use app\util\SMTRwDto;

/**
 * 
 * @author Sylvain Desplat
 */
class SMTCustomFirewallDto extends SMTRwDto
{
	protected $customFirewallConfig = array();
		
	/**
	 * Set array of port where email must be sent
	 * 
	 * @param string[] $customFirewallConfig
	 */
	public function setCustomFirewall( array $customFirewallConfig )
	{
		$this->customFirewallConfig = $customFirewallConfig;
	}
	
	/**
	 * @return String[]
	 */
	public function getCustomFirewall()
	{
		return $this->customFirewallConfig;
	}
	
	public function stripHtmlTags()
	{
		$this->customFirewallConfig= array_map('strip_tags', $this->customFirewallConfig);
	}
	
	/**
	 * Serialize as Json data the user object.<br>
	 *
	 * @return $objectProperties the object properties serialized as a Json string.
	 */
	function getJsonData()
	{
		$objectProperties = get_object_vars($this);
		$this->serializeObjectAsJsonData( $objectProperties );
		return $objectProperties;
	}

	/**
	 * Returns Dto class name.
	 *
	 * @return string the dtop class name
	 */
	function getDtoClassName()
	{
		return get_class();
	}

	/**
	 * Create the Dto from a Json Dto in an array
	 *
	 * @param array $json_array json data in an array
	 *
	 * @return \app\services\setup\SMTEmailPortFilterDto
	 */
	static function getInstance( array &$json_array )
	{
		$instance = self::forge( get_class(), $json_array );
		$instance->stripHtmlTags();
		return $instance;
	}
}


?>
